@@ -4,4 +4,11 @@ class InquiryResponseBody:
     def __init__(self, responseCode: str, responseMessage: str, virtualAccountData: InquiryRequestVirtualAccountData = None) -> None:
         self.response_code = responseCode
         self.response_message = responseMessage
-        self.virtual_account_data = virtualAccountData
\ No newline at end of file
+        self.virtual_account_data = virtualAccountData
+    
+    def json(self) -> dict:
+        return {
+            "responseCode": self.response_code,
+            "responseMessage": self.response_message,
+            "virtualAccountData": self.virtual_account_data.json()
+        }
\ No newline at end of file
